.. shorttext documentation master file, created by
   sphinx-quickstart on Sun Dec 11 16:15:57 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to shorttext's documentation!
=====================================

This repository is a collection of algorithms for multi-class classification to short texts using Python.
Modules are backward compatible unless otherwise specified. Feel free to give suggestions or report
issues through the Github_ page.

Contents:

.. toctree::
   :maxdepth: 2

   install
   doclink
   codes

Links:

- Github_ : repository of the package
- PyPI_ : PyPI


.. _Github: https://github.com/stephenhky/PyShortTextCategorization
.. _PyPI: https://pypi.org/project/shorttext/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

